Documentation
¶
Overview ¶
Package app implements a Server object for running the autoscaler.
Package app implements a Server object for running the autoscaler.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAutoscalerCommand ¶
NewAutoscalerCommand creates a *cobra.Command object with default parameters
func Run ¶
func Run(c *config.PixiuConfiguration) error
Run runs the pixiu-autoscaler process. This should never exit.
func StartHealthzServer ¶
Types ¶
type ControllerContext ¶
type ControllerContext struct {
// ClientBuilder will provide a client for this controller to use
ClientBuilder controller.ControllerClientBuilder
// InformerFactory gives access to informers for the controller.
InformerFactory informers.SharedInformerFactory
ObjectOrMetadataInformerFactory controller.InformerFactory
// Stop is the stop channel
Stop <-chan struct{}
// ResyncPeriod generates a duration each time it is invoked; this is so that
// multiple controllers don't get into lock-step and all hammer the apiserver
// with list requests simultaneously.
ResyncPeriod func() time.Duration
}
ControllerContext defines the context obj for pixiu-autoscaler
func CreateControllerContext ¶
func CreateControllerContext(rootClientBuilder, clientBuilder controller.ControllerClientBuilder, stop <-chan struct{}) (ControllerContext, error)
Click to show internal directories.
Click to hide internal directories.